@@ -24,14 +24,14 @@
 
 #include "SFCGAL/export.h"
 
-#define SFCGAL_VERSION_MAJOR @SFCGAL_VERSION_MAJOR @
-#define SFCGAL_VERSION_MINOR @SFCGAL_VERSION_MINOR @
-#define SFCGAL_VERSION_PATCH @SFCGAL_VERSION_PATCH @
+#define SFCGAL_VERSION_MAJOR 2
+#define SFCGAL_VERSION_MINOR 2
+#define SFCGAL_VERSION_PATCH 0
 
-#define SFCGAL_VERSION "2.0.0"
+#define SFCGAL_VERSION "2.2.0"
 
 #define SFCGAL_FULL_VERSION                                                    \
-  "SFCGAL 2.0.0, CGAL 6.0, BOOST 1.81.0"
+  "SFCGAL 2.2.0, CGAL 6.0.1, BOOST 1.81.0"
 
 namespace SFCGAL {
 SFCGAL_API const char *
